#!/bin/sh
set -ev

ROOT=$(dirname $(dirname $(realpath "${0}")))

# Build documentation
cd ${ROOT}/doc
make html

# Build basic.tar
cd ${ROOT}/vm
tar cpf /srv/build/vm.tar *

# Build native apps
cd ${ROOT}/apk/acme-sh
abuild -F

cd ${ROOT}/apk/geos
apk add -U swig python2-dev
abuild -F

cd ${ROOT}/apk/gdal
apk add -U curl-dev geos-dev@vm giflib-dev jpeg-dev libjpeg-turbo-dev libpng-dev linux-headers postgresql-dev python2-dev sqlite-dev swig tiff-dev zlib-dev
abuild -F

cd ${ROOT}/apk/proj4
abuild -F

cd ${ROOT}/apk/rabbitmq-server
apk add -U elixir erlang-compiler erlang-dev erlang-edoc erlang-eldap erlang-erl-docgen erlang-mnesia erlang-os-mon erlang-runtime-tools erlang-tools erlang-xmerl gawk grep libxslt logrotate py2-simplejson python2 rsync socat xmlto zip
abuild -F

cd ${ROOT}/apk/postgis
apk add -U gdal-dev@vm geos-dev@vm json-c-dev libxml2-dev pcre-dev perl perl-dev postgresql postgresql-dev proj4-dev@vm
abuild -F

cd ${ROOT}/apk/vmmgr
abuild -F

cd ${ROOT}/apk/wireguard
apk add -U libmnl-dev linux-virt-dev linux-firmware-none
FLAVOR=virt abuild -F

cd ${ROOT}/apk/wireguard-tools
apk add -U libmnl-dev
abuild -F

# Build apd pack runtimes
cd ${ROOT}/lxc-shared
lxcbuild alpine3.8
lxcbuild alpine3.8-php5.6
lxcbuild alpine3.8-nodejs8
lxcbuild alpine3.8-ruby2.4
lxcbuild alpine3.9
lxcbuild alpine3.9-java8
lxcbuild alpine3.9-php7.2
lxcbuild alpine3.9-python2.7
lxcbuild alpine3.9-python3.6
lxcbuild alpine3.9-nodejs10
lxcbuild alpine3.9-ruby2.4
lxcbuild alpine3.9-tomcat7
lxcbuild alpine3.9-tomcat8.5

# Build services
cd ${ROOT}/lxc-services
lxcbuild activemq
lxcbuild mariadb
lxcbuild postgres
lxcbuild postgis
lxcbuild rabbitmq
lxcbuild redis
lxcbuild solr6

# Build applications
cd ${ROOT}/lxc-apps
lxcbuild ckan
lxcbuild ckan-datapusher
lxcbuild crisiscleanup
lxcbuild cts
lxcbuild ecogis
lxcbuild frontlinesms
lxcbuild gnuhealth
lxcbuild kanboard
lxcbuild mifosx
lxcbuild motech
lxcbuild odoo
lxcbuild opendatakit
lxcbuild opendatakit-build
lxcbuild openmapkit
lxcbuild pandora
lxcbuild sahana-shared
lxcbuild sahana
lxcbuild sahana-demo
lxcbuild sambro
lxcbuild seeddms
lxcbuild sigmah
lxcbuild ushahidi
